"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const themis_validation_core_1 = require("themis-validation-core");
const themis_validation_rules_common_filter_1 = require("themis-validation-rules-common-filter");
class VueControllerValidation extends themis_validation_core_1.ObjectValidation {
    constructor() {
        super(...arguments);
        this.disabledGroups = [];
    }
    init(defaultValueRetriever, objectValidationConfig) {
        this.defaultValueRetriever = defaultValueRetriever;
        this.objectValidationConfig = objectValidationConfig;
    }
    isComponentInvalid() {
        return this.objectValidationConfig.isInvalid(this.defaultValueRetriever, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups));
    }
    getComponentErrors() {
        return this.objectValidationConfig.getErrors(this.defaultValueRetriever, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups));
    }
    getComponentErrosWithoutMandatoryRules() {
        return this.objectValidationConfig.getErrors(this.defaultValueRetriever, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups), new themis_validation_rules_common_filter_1.MandatoryRuleFilter());
    }
    getFieldErrors(fieldName) {
        let fieldScopeFilter = new themis_validation_core_1.FieldScopeFilter(fieldName);
        let filter = new themis_validation_core_1.AndScopeFilter(fieldScopeFilter, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups));
        return this.objectValidationConfig.getErrors(this.defaultValueRetriever, filter);
    }
    getFieldErrorTexts(fieldName, textProcessor) {
        let fieldErrors = this.getFieldErrors(fieldName);
        var errorMessages = [];
        for (const fieldError of fieldErrors) {
            for (const validationRuleError of fieldError.validationRuleErrors) {
                errorMessages.push(validationRuleError.validationRule.getErrorText(textProcessor));
            }
        }
        return errorMessages;
    }
    isFieldInvalid(fieldName) {
        let fieldScopeFilter = new themis_validation_core_1.FieldScopeFilter(fieldName);
        let filter = new themis_validation_core_1.AndScopeFilter(fieldScopeFilter, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups));
        return this.objectValidationConfig.isInvalid(this.defaultValueRetriever, filter);
    }
    isFieldInvalidWithValue(fieldName, value) {
        let fieldScopeFilter = new themis_validation_core_1.FieldScopeFilter(fieldName);
        let filter = new themis_validation_core_1.AndScopeFilter(fieldScopeFilter, new themis_validation_core_1.NotInDisabledGroupScopeFilter(this.disabledGroups));
        return this.objectValidationConfig.isInvalid(new themis_validation_core_1.DirectRetriever(value), filter);
    }
    disableGroup(groupName) {
        this.disabledGroups.push(groupName);
    }
    enableGroup(groupName) {
        this.disabledGroups = this.disabledGroups.filter(obj => obj !== groupName);
    }
    clearDisabledGroups() {
        this.disabledGroups = [];
    }
}
exports.VueControllerValidation = VueControllerValidation;
//# sourceMappingURL=VueControllerValidation.js.map